@@ -12,10 +12,23 @@ Usage::
 import sys
 from typing import IO, Dict, List, Union
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
+from mypy_boto3_appsync.literals import (
+    ApiCacheStatus,
+    ApiCacheType,
+    ApiCachingBehavior,
+    AuthenticationType,
+    AuthorizationType,
+    ConflictDetectionType,
+    ConflictHandlerType,
+    DataSourceType,
+    DefaultAction,
+    FieldLogLevel,
+    RelationalDatabaseSourceType,
+    ResolverKind,
+    SchemaStatus,
+    TypeDefinitionFormat,
+)
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -85,9 +98,7 @@ __all__ = (
 AdditionalAuthenticationProviderTypeDef = TypedDict(
     "AdditionalAuthenticationProviderTypeDef",
     {
-        "authenticationType": Literal[
-            "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
-        ],
+        "authenticationType": AuthenticationType,
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
         "userPoolConfig": "CognitoUserPoolConfigTypeDef",
     },
@@ -98,27 +109,11 @@ ApiCacheTypeDef = TypedDict(
     "ApiCacheTypeDef",
     {
         "ttl": int,
-        "apiCachingBehavior": Literal["FULL_REQUEST_CACHING", "PER_RESOLVER_CACHING"],
+        "apiCachingBehavior": ApiCachingBehavior,
         "transitEncryptionEnabled": bool,
         "atRestEncryptionEnabled": bool,
-        "type": Literal[
-            "T2_SMALL",
-            "T2_MEDIUM",
-            "R4_LARGE",
-            "R4_XLARGE",
-            "R4_2XLARGE",
-            "R4_4XLARGE",
-            "R4_8XLARGE",
-            "SMALL",
-            "MEDIUM",
-            "LARGE",
-            "XLARGE",
-            "LARGE_2X",
-            "LARGE_4X",
-            "LARGE_8X",
-            "LARGE_12X",
-        ],
-        "status": Literal["AVAILABLE", "CREATING", "DELETING", "MODIFYING", "FAILED"],
+        "type": ApiCacheType,
+        "status": ApiCacheStatus,
     },
     total=False,
 )
@@ -128,7 +123,7 @@ ApiKeyTypeDef = TypedDict(
 )
 
 _RequiredAuthorizationConfigTypeDef = TypedDict(
-    "_RequiredAuthorizationConfigTypeDef", {"authorizationType": Literal["AWS_IAM"]}
+    "_RequiredAuthorizationConfigTypeDef", {"authorizationType": AuthorizationType}
 )
 _OptionalAuthorizationConfigTypeDef = TypedDict(
     "_OptionalAuthorizationConfigTypeDef", {"awsIamConfig": "AwsIamConfigTypeDef"}, total=False
@@ -169,14 +164,7 @@ DataSourceTypeDef = TypedDict(
         "dataSourceArn": str,
         "name": str,
         "description": str,
-        "type": Literal[
-            "AWS_LAMBDA",
-            "AMAZON_DYNAMODB",
-            "AMAZON_ELASTICSEARCH",
-            "NONE",
-            "HTTP",
-            "RELATIONAL_DATABASE",
-        ],
+        "type": DataSourceType,
         "serviceRoleArn": str,
         "dynamodbConfig": "DynamodbDataSourceConfigTypeDef",
         "lambdaConfig": "LambdaDataSourceConfigTypeDef",
@@ -234,9 +222,7 @@ GraphqlApiTypeDef = TypedDict(
     {
         "name": str,
         "apiId": str,
-        "authenticationType": Literal[
-            "API_KEY", "AWS_IAM", "AMAZON_COGNITO_USER_POOLS", "OPENID_CONNECT"
-        ],
+        "authenticationType": AuthenticationType,
         "logConfig": "LogConfigTypeDef",
         "userPoolConfig": "UserPoolConfigTypeDef",
         "openIDConnectConfig": "OpenIDConnectConfigTypeDef",
@@ -265,8 +251,7 @@ LambdaDataSourceConfigTypeDef = TypedDict(
 )
 
 _RequiredLogConfigTypeDef = TypedDict(
-    "_RequiredLogConfigTypeDef",
-    {"fieldLogLevel": Literal["NONE", "ERROR", "ALL"], "cloudWatchLogsRoleArn": str},
+    "_RequiredLogConfigTypeDef", {"fieldLogLevel": FieldLogLevel, "cloudWatchLogsRoleArn": str}
 )
 _OptionalLogConfigTypeDef = TypedDict(
     "_OptionalLogConfigTypeDef", {"excludeVerboseContent": bool}, total=False
@@ -310,7 +295,7 @@ RdsHttpEndpointConfigTypeDef = TypedDict(
 RelationalDatabaseDataSourceConfigTypeDef = TypedDict(
     "RelationalDatabaseDataSourceConfigTypeDef",
     {
-        "relationalDatabaseSourceType": Literal["RDS_HTTP_ENDPOINT"],
+        "relationalDatabaseSourceType": RelationalDatabaseSourceType,
         "rdsHttpEndpointConfig": "RdsHttpEndpointConfigTypeDef",
     },
     total=False,
@@ -325,7 +310,7 @@ ResolverTypeDef = TypedDict(
         "resolverArn": str,
         "requestMappingTemplate": str,
         "responseMappingTemplate": str,
-        "kind": Literal["UNIT", "PIPELINE"],
+        "kind": ResolverKind,
         "pipelineConfig": "PipelineConfigTypeDef",
         "syncConfig": "SyncConfigTypeDef",
         "cachingConfig": "CachingConfigTypeDef",
@@ -336,8 +321,8 @@ ResolverTypeDef = TypedDict(
 SyncConfigTypeDef = TypedDict(
     "SyncConfigTypeDef",
     {
-        "conflictHandler": Literal["OPTIMISTIC_CONCURRENCY", "LAMBDA", "AUTOMERGE", "NONE"],
-        "conflictDetection": Literal["VERSION", "NONE"],
+        "conflictHandler": ConflictHandlerType,
+        "conflictDetection": ConflictDetectionType,
         "lambdaConflictHandlerConfig": "LambdaConflictHandlerConfigTypeDef",
     },
     total=False,
@@ -350,14 +335,14 @@ TypeTypeDef = TypedDict(
         "description": str,
         "arn": str,
         "definition": str,
-        "format": Literal["SDL", "JSON"],
+        "format": TypeDefinitionFormat,
     },
     total=False,
 )
 
 _RequiredUserPoolConfigTypeDef = TypedDict(
     "_RequiredUserPoolConfigTypeDef",
-    {"userPoolId": str, "awsRegion": str, "defaultAction": Literal["ALLOW", "DENY"]},
+    {"userPoolId": str, "awsRegion": str, "defaultAction": DefaultAction},
 )
 _OptionalUserPoolConfigTypeDef = TypedDict(
     "_OptionalUserPoolConfigTypeDef", {"appIdClientRegex": str}, total=False
@@ -425,14 +410,7 @@ GetResolverResponseTypeDef = TypedDict(
 )
 
 GetSchemaCreationStatusResponseTypeDef = TypedDict(
-    "GetSchemaCreationStatusResponseTypeDef",
-    {
-        "status": Literal[
-            "PROCESSING", "ACTIVE", "DELETING", "FAILED", "SUCCESS", "NOT_APPLICABLE"
-        ],
-        "details": str,
-    },
-    total=False,
+    "GetSchemaCreationStatusResponseTypeDef", {"status": SchemaStatus, "details": str}, total=False
 )
 
 GetTypeResponseTypeDef = TypedDict("GetTypeResponseTypeDef", {"type": "TypeTypeDef"}, total=False)
@@ -484,9 +462,7 @@ PaginatorConfigTypeDef = TypedDict(
 )
 
 StartSchemaCreationResponseTypeDef = TypedDict(
-    "StartSchemaCreationResponseTypeDef",
-    {"status": Literal["PROCESSING", "ACTIVE", "DELETING", "FAILED", "SUCCESS", "NOT_APPLICABLE"]},
-    total=False,
+    "StartSchemaCreationResponseTypeDef", {"status": SchemaStatus}, total=False
 )
 
 UpdateApiCacheResponseTypeDef = TypedDict(
